==> libnetconf-0.9.1.tar.gz: libnetconf/doc/doxygen/html/db/de9/group__rpc.js <==
var group__rpc =
[
    [ "nc_rpc", "db/de9/group__rpc.html#gab21d1d39737065c552f2ccc5b4819262", null ],
    [ "NC_CAP_ATTR", "db/de9/group__rpc.html#ga06a2c29efc74abd4d0c88e7abb5e914d", [
      [ "NC_CAP_ATTR_WITHDEFAULTS_MODE", "db/de9/group__rpc.html#gga06a2c29efc74abd4d0c88e7abb5e914dadef4f6d77cebdc7c004db1f5f5f612ba", null ]
    ] ],
    [ "NC_EDIT_DEFOP_TYPE", "db/de9/group__rpc.html#ga5852fd110198481afb37cc8dcf0bf454", [
      [ "NC_EDIT_DEFOP_ERROR", "db/de9/group__rpc.html#gga5852fd110198481afb37cc8dcf0bf454ab2b415d864a2f84bf6e0e31abe56d187", null ],
      [ "NC_EDIT_DEFOP_NOTSET", "db/de9/group__rpc.html#gga5852fd110198481afb37cc8dcf0bf454ae959e6f9ed31a8e4441ad84eae8b43d2", null ],
      [ "NC_EDIT_DEFOP_MERGE", "db/de9/group__rpc.html#gga5852fd110198481afb37cc8dcf0bf454a5242dcc6a090887ef8b3f6c96b1b4931", null ],
      [ "NC_EDIT_DEFOP_REPLACE", "db/de9/group__rpc.html#gga5852fd110198481afb37cc8dcf0bf454a80cda5b10ba3ff7f819c08508be9237c", null ],
      [ "NC_EDIT_DEFOP_NONE", "db/de9/group__rpc.html#gga5852fd110198481afb37cc8dcf0bf454a37dd969ad73f6ac990785d9802672946", null ]
    ] ],
    [ "NC_EDIT_ERROPT_TYPE", "db/de9/group__rpc.html#ga8eb32ba579043f2750fa8558d9284b32", [
      [ "NC_EDIT_ERROPT_ERROR", "db/de9/group__rpc.html#gga8eb32ba579043f2750fa8558d9284b32a9a174d6de80e8ea7d2267d550061f4b4", null ],
      [ "NC_EDIT_ERROPT_NOTSET", "db/de9/group__rpc.html#gga8eb32ba579043f2750fa8558d9284b32a8f01a1f484abf78c8c0ea3f2d369306e", null ],
      [ "NC_EDIT_ERROPT_STOP", "db/de9/group__rpc.html#gga8eb32ba579043f2750fa8558d9284b32ae3322bea978cea2d2a7c0818680bd721", null ],
      [ "NC_EDIT_ERROPT_CONT", "db/de9/group__rpc.html#gga8eb32ba579043f2750fa8558d9284b32a69d82c66a324215010791718c1bc61f6", null ],
      [ "NC_EDIT_ERROPT_ROLLBACK", "db/de9/group__rpc.html#gga8eb32ba579043f2750fa8558d9284b32a35128042558e32842f827be8c31d5b1a", null ]
    ] ],
    [ "NC_EDIT_OP_TYPE", "db/de9/group__rpc.html#gaff232fd4280e385c8e45fcca033e58fd", [
      [ "NC_EDIT_OP_ERROR", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fda0edecb3360a233e6d2d8435a96a3e54f", null ],
      [ "NC_EDIT_OP_MERGE", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fda269b9d38aa530c9cfe21b5477e328e0c", null ],
      [ "NC_EDIT_OP_REPLACE", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fda5d2ca68f21babd6220538a1e3eac2356", null ],
      [ "NC_EDIT_OP_CREATE", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fdaa7f202a2d5f43e094946b1361da93f40", null ],
      [ "NC_EDIT_OP_DELETE", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fdaf85c0828113a86cb30dd67991e19b6ba", null ],
      [ "NC_EDIT_OP_REMOVE", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fda5c6473715392eb03614abc6d7e62bdf9", null ]
    ] ],
    [ "NC_EDIT_TESTOPT_TYPE", "db/de9/group__rpc.html#gaca86efe74fc9a26cc30e33a8e9772579", [
      [ "NC_EDIT_TESTOPT_ERROR", "db/de9/group__rpc.html#ggaca86efe74fc9a26cc30e33a8e9772579a1770ae5b90495ca720f60ca76ab029b4", null ],
      [ "NC_EDIT_TESTOPT_NOTSET", "db/de9/group__rpc.html#ggaca86efe74fc9a26cc30e33a8e9772579acb24b46f501c50f2a78b87da73322bc7", null ],
      [ "NC_EDIT_TESTOPT_TESTSET", "db/de9/group__rpc.html#ggaca86efe74fc9a26cc30e33a8e9772579aae2180fb26e03b4c1ea184abb463056c", null ],
      [ "NC_EDIT_TESTOPT_SET", "db/de9/group__rpc.html#ggaca86efe74fc9a26cc30e33a8e9772579a56b353b9c45d7eed3373e41feb509294", null ],
      [ "NC_EDIT_TESTOPT_TEST", "db/de9/group__rpc.html#ggaca86efe74fc9a26cc30e33a8e9772579a7f8086cbfcc1c1811b33e2d681f77072", null ]
    ] ],
    [ "NC_FILTER_TYPE", "db/de9/group__rpc.html#ga9e74498f9118686c7fb8dfe2c2459706", [
      [ "NC_FILTER_UNKNOWN", "db/de9/group__rpc.html#gga9e74498f9118686c7fb8dfe2c2459706a487f472296b31fcec26a2bef87d50178", null ],
      [ "NC_FILTER_SUBTREE", "db/de9/group__rpc.html#gga9e74498f9118686c7fb8dfe2c2459706ab584539474b828102a0b7238b614abd4", null ]
    ] ],
    [ "NC_OP", "db/de9/group__rpc.html#ga3e6fc59e2d06c1c0edb36ee64ee9cc07", [
      [ "NC_OP_UNKNOWN", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a7ca4781a2c8644c3c15e3b0cd9116090", null ],
      [ "NC_OP_GETCONFIG", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a9f918e6ed1c58fb70ffe4cbd05882332", null ],
      [ "NC_OP_GET", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07ae7c153c569fe9ca06532dadc41dce78f", null ],
      [ "NC_OP_EDITCONFIG", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a545f2b8ad13fc1cb449f078908312ef1", null ],
      [ "NC_OP_CLOSESESSION", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07af5cc206ce4cd2b20cd562bb01e0a8da3", null ],
      [ "NC_OP_KILLSESSION", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a01a1b829ca743ac8f8e8444d71f16d0d", null ],
      [ "NC_OP_COPYCONFIG", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07abc36a612cfba2cf3462d99fae4ab4ac5", null ],
      [ "NC_OP_DELETECONFIG", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07abf39ac97e04fd8d77d6a409a004eb234", null ],
      [ "NC_OP_LOCK", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07af07ffd285bc743fcbdeace96f2b21d22", null ],
      [ "NC_OP_UNLOCK", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07aa4071db38c423865b24543cb504a4b42", null ],
      [ "NC_OP_COMMIT", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a350f96fd686eea971d1d9e087a9ff8f4", null ],
      [ "NC_OP_DISCARDCHANGES", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a59fd75a1b96a307a2d87e327c7d9a695", null ],
      [ "NC_OP_CREATESUBSCRIPTION", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07aafc549220669ed05b9c043b09be496fe", null ],
      [ "NC_OP_GETSCHEMA", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a213f30aeb2d0d09bc6de7d98015860c3", null ],
      [ "NC_OP_VALIDATE", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a064e97e228090350548b4b67c6c598b0", null ]
    ] ],
    [ "NC_RPC_TYPE", "db/de9/group__rpc.html#ga4088fac1dd592062b27ff5b0e1708d00", [
      [ "NC_RPC_UNKNOWN", "db/de9/group__rpc.html#gga4088fac1dd592062b27ff5b0e1708d00ae27a06c29d4cb56cce4298bc54dc498a", null ],
      [ "NC_RPC_HELLO", "db/de9/group__rpc.html#gga4088fac1dd592062b27ff5b0e1708d00a4c352cf3bf15069fc76e4ac698de0a8c", null ],
      [ "NC_RPC_DATASTORE_READ", "db/de9/group__rpc.html#gga4088fac1dd592062b27ff5b0e1708d00ab9542d7955d9821f23b5909f3dbec7bb", null ],
      [ "NC_RPC_DATASTORE_WRITE", "db/de9/group__rpc.html#gga4088fac1dd592062b27ff5b0e1708d00ab283d1c39df65fe56607329bc3c946f9", null ],
      [ "NC_RPC_SESSION", "db/de9/group__rpc.html#gga4088fac1dd592062b27ff5b0e1708d00aa7e77d1cd094384f2683352c63a4fccb", null ]
    ] ],
    [ "nc_filter_free", "db/de9/group__rpc.html#ga0dbfd598d6fd303819817370cdf63229", null ],
    [ "nc_filter_new", "db/de9/group__rpc.html#ga599c715b0aee0f1f2ed231ce1d78e5bd", null ],
    [ "nc_rpc_build", "db/de9/group__rpc.html#ga5c4348c96b0d5e6a64f94dbbdeaf4100", null ],
    [ "nc_rpc_capability_attr", "db/de9/group__rpc.html#ga14f5e170cbc9acd9a146eee2fb6b796f", null ],
    [ "nc_rpc_commit", "db/de9/group__rpc.html#ga7977ca8b562643607b3c846ed36bbb23", null ],
    [ "nc_rpc_copyconfig", "db/de9/group__rpc.html#gaf7b76c1243dc218cf1dc8b17876e319c", null ],
    [ "nc_rpc_deleteconfig", "db/de9/group__rpc.html#gae1faa46f5048f21dc580d44836d848e8", null ],
    [ "nc_rpc_discardchanges", "db/de9/group__rpc.html#ga337ea7a9b006a79ee5ea615e9d9a5a6f", null ],
    [ "nc_rpc_dump", "db/de9/group__rpc.html#ga3e840368c40be2ea4d5201edbd3adaca", null ],
    [ "nc_rpc_dup", "db/de9/group__rpc.html#gadab3d916540f79dd2b168134758fe3d1", null ],
    [ "nc_rpc_editconfig", "db/de9/group__rpc.html#gae704e312c7aa5e6385abd4989e79398c", null ],
    [ "nc_rpc_free", "db/de9/group__rpc.html#ga4041bda37caa9eedb7a1e2534280f3df", null ],
    [ "nc_rpc_generic", "db/de9/group__rpc.html#gaa9ad7fac41fdef0063c2e2793fb19efd", null ],
    [ "nc_rpc_get", "db/de9/group__rpc.html#ga6818afbecf7fedf78f620162de78b4fd", null ],
    [ "nc_rpc_get_config", "db/de9/group__rpc.html#ga05a10e0b6c89ac04426410f399b87257", null ],
    [ "nc_rpc_get_defop", "db/de9/group__rpc.html#gaf867eacee93e3596371415d028e62d29", null ],
    [ "nc_rpc_get_erropt", "db/de9/group__rpc.html#ga488f894b9fa4866326837a9ed0575e36", null ],
    [ "nc_rpc_get_filter", "db/de9/group__rpc.html#ga05705bba8345c15637bc54cf6b9a4b3d", null ],
    [ "nc_rpc_get_msgid", "db/de9/group__rpc.html#gabc7eb11a4f2fdbe302a2430e00935c48", null ],
    [ "nc_rpc_get_ns", "db/de9/group__rpc.html#ga21ae2135af2588162112c13fb4095652", null ],
    [ "nc_rpc_get_op", "db/de9/group__rpc.html#gabf639574395456fb6f4bade36fb4babd", null ],
    [ "nc_rpc_get_op_content", "db/de9/group__rpc.html#gade3f111e7c7727d512313b4875fd8f50", null ],
    [ "nc_rpc_get_op_name", "db/de9/group__rpc.html#ga9796f2bc7841265d478891974eb610c6", null ],
    [ "nc_rpc_get_op_namespace", "db/de9/group__rpc.html#ga0b5d7acbcc0429fac6d5e3b509609bd8", null ],
    [ "nc_rpc_get_source", "db/de9/group__rpc.html#ga3fcf5083b04a294e935a2897c212065b", null ],
    [ "nc_rpc_get_target", "db/de9/group__rpc.html#gab240067d45d58c945cdfd61948751379", null ],
    [ "nc_rpc_get_testopt", "db/de9/group__rpc.html#gab12fec9068d72fa6817f4a59a81e625e", null ],
    [ "nc_rpc_get_type", "db/de9/group__rpc.html#gaa502fb30575000775b29a764101c1bef", null ],
    [ "nc_rpc_getconfig", "db/de9/group__rpc.html#ga4ae747c4c96e1d3621745e122091ba11", null ],
    [ "nc_rpc_getschema", "db/de9/group__rpc.html#ga3b762dd881622eaa72b08c9b58d76a5e", null ],
    [ "nc_rpc_killsession", "db/de9/group__rpc.html#gae9876e8d038eb81a376bd82a08c58b95", null ],
    [ "nc_rpc_lock", "db/de9/group__rpc.html#ga6a03d40e00fbe019a34541a55f3f4a31", null ],
    [ "nc_rpc_unlock", "db/de9/group__rpc.html#gad843551f9d1ff8be6a118d026e8b995a", null ],
    [ "nc_rpc_validate", "db/de9/group__rpc.html#ga14fa1c78362457a646d5d820206d5158", null ],
    [ "nc_session_recv_rpc", "db/de9/group__rpc.html#ga214fcc2c0095d56f4aa0d90c11da25fc", null ],
    [ "nc_session_send_recv", "db/de9/group__rpc.html#ga27d3fe78769630932a18c726df4fe6e6", null ],
    [ "nc_session_send_rpc", "db/de9/group__rpc.html#gaeb0d93ea1b5ef0c22c9e5372425fb5c3", null ]
];

==> libnetconf-0.10.0.tar.gz: libnetconf/doc/doxygen/html/db/de9/group__rpc.js <==
var group__rpc =
[
    [ "nc_rpc", "db/de9/group__rpc.html#gab21d1d39737065c552f2ccc5b4819262", null ],
    [ "NC_CAP_ATTR", "db/de9/group__rpc.html#ga06a2c29efc74abd4d0c88e7abb5e914d", [
      [ "NC_CAP_ATTR_WITHDEFAULTS_MODE", "db/de9/group__rpc.html#gga06a2c29efc74abd4d0c88e7abb5e914dadef4f6d77cebdc7c004db1f5f5f612ba", null ]
    ] ],
    [ "NC_EDIT_DEFOP_TYPE", "db/de9/group__rpc.html#ga5852fd110198481afb37cc8dcf0bf454", [
      [ "NC_EDIT_DEFOP_ERROR", "db/de9/group__rpc.html#gga5852fd110198481afb37cc8dcf0bf454ab2b415d864a2f84bf6e0e31abe56d187", null ],
      [ "NC_EDIT_DEFOP_NOTSET", "db/de9/group__rpc.html#gga5852fd110198481afb37cc8dcf0bf454ae959e6f9ed31a8e4441ad84eae8b43d2", null ],
      [ "NC_EDIT_DEFOP_MERGE", "db/de9/group__rpc.html#gga5852fd110198481afb37cc8dcf0bf454a5242dcc6a090887ef8b3f6c96b1b4931", null ],
      [ "NC_EDIT_DEFOP_REPLACE", "db/de9/group__rpc.html#gga5852fd110198481afb37cc8dcf0bf454a80cda5b10ba3ff7f819c08508be9237c", null ],
      [ "NC_EDIT_DEFOP_NONE", "db/de9/group__rpc.html#gga5852fd110198481afb37cc8dcf0bf454a37dd969ad73f6ac990785d9802672946", null ]
    ] ],
    [ "NC_EDIT_ERROPT_TYPE", "db/de9/group__rpc.html#ga8eb32ba579043f2750fa8558d9284b32", [
      [ "NC_EDIT_ERROPT_ERROR", "db/de9/group__rpc.html#gga8eb32ba579043f2750fa8558d9284b32a9a174d6de80e8ea7d2267d550061f4b4", null ],
      [ "NC_EDIT_ERROPT_NOTSET", "db/de9/group__rpc.html#gga8eb32ba579043f2750fa8558d9284b32a8f01a1f484abf78c8c0ea3f2d369306e", null ],
      [ "NC_EDIT_ERROPT_STOP", "db/de9/group__rpc.html#gga8eb32ba579043f2750fa8558d9284b32ae3322bea978cea2d2a7c0818680bd721", null ],
      [ "NC_EDIT_ERROPT_CONT", "db/de9/group__rpc.html#gga8eb32ba579043f2750fa8558d9284b32a69d82c66a324215010791718c1bc61f6", null ],
      [ "NC_EDIT_ERROPT_ROLLBACK", "db/de9/group__rpc.html#gga8eb32ba579043f2750fa8558d9284b32a35128042558e32842f827be8c31d5b1a", null ]
    ] ],
    [ "NC_EDIT_OP_TYPE", "db/de9/group__rpc.html#gaff232fd4280e385c8e45fcca033e58fd", [
      [ "NC_EDIT_OP_ERROR", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fda0edecb3360a233e6d2d8435a96a3e54f", null ],
      [ "NC_EDIT_OP_MERGE", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fda269b9d38aa530c9cfe21b5477e328e0c", null ],
      [ "NC_EDIT_OP_NOTSET", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fda973d70fee8360757be1f9379334a5ecb", null ],
      [ "NC_EDIT_OP_REPLACE", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fda5d2ca68f21babd6220538a1e3eac2356", null ],
      [ "NC_EDIT_OP_CREATE", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fdaa7f202a2d5f43e094946b1361da93f40", null ],
      [ "NC_EDIT_OP_DELETE", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fdaf85c0828113a86cb30dd67991e19b6ba", null ],
      [ "NC_EDIT_OP_REMOVE", "db/de9/group__rpc.html#ggaff232fd4280e385c8e45fcca033e58fda5c6473715392eb03614abc6d7e62bdf9", null ]
    ] ],
    [ "NC_EDIT_TESTOPT_TYPE", "db/de9/group__rpc.html#gaca86efe74fc9a26cc30e33a8e9772579", [
      [ "NC_EDIT_TESTOPT_ERROR", "db/de9/group__rpc.html#ggaca86efe74fc9a26cc30e33a8e9772579a1770ae5b90495ca720f60ca76ab029b4", null ],
      [ "NC_EDIT_TESTOPT_NOTSET", "db/de9/group__rpc.html#ggaca86efe74fc9a26cc30e33a8e9772579acb24b46f501c50f2a78b87da73322bc7", null ],
      [ "NC_EDIT_TESTOPT_TESTSET", "db/de9/group__rpc.html#ggaca86efe74fc9a26cc30e33a8e9772579aae2180fb26e03b4c1ea184abb463056c", null ],
      [ "NC_EDIT_TESTOPT_SET", "db/de9/group__rpc.html#ggaca86efe74fc9a26cc30e33a8e9772579a56b353b9c45d7eed3373e41feb509294", null ],
      [ "NC_EDIT_TESTOPT_TEST", "db/de9/group__rpc.html#ggaca86efe74fc9a26cc30e33a8e9772579a7f8086cbfcc1c1811b33e2d681f77072", null ]
    ] ],
    [ "NC_FILTER_TYPE", "db/de9/group__rpc.html#ga9e74498f9118686c7fb8dfe2c2459706", [
      [ "NC_FILTER_UNKNOWN", "db/de9/group__rpc.html#gga9e74498f9118686c7fb8dfe2c2459706a487f472296b31fcec26a2bef87d50178", null ],
      [ "NC_FILTER_SUBTREE", "db/de9/group__rpc.html#gga9e74498f9118686c7fb8dfe2c2459706ab584539474b828102a0b7238b614abd4", null ]
    ] ],
    [ "NC_OP", "db/de9/group__rpc.html#ga3e6fc59e2d06c1c0edb36ee64ee9cc07", [
      [ "NC_OP_UNKNOWN", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a7ca4781a2c8644c3c15e3b0cd9116090", null ],
      [ "NC_OP_GETCONFIG", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a9f918e6ed1c58fb70ffe4cbd05882332", null ],
      [ "NC_OP_GET", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07ae7c153c569fe9ca06532dadc41dce78f", null ],
      [ "NC_OP_EDITCONFIG", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a545f2b8ad13fc1cb449f078908312ef1", null ],
      [ "NC_OP_CLOSESESSION", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07af5cc206ce4cd2b20cd562bb01e0a8da3", null ],
      [ "NC_OP_KILLSESSION", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a01a1b829ca743ac8f8e8444d71f16d0d", null ],
      [ "NC_OP_COPYCONFIG", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07abc36a612cfba2cf3462d99fae4ab4ac5", null ],
      [ "NC_OP_DELETECONFIG", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07abf39ac97e04fd8d77d6a409a004eb234", null ],
      [ "NC_OP_LOCK", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07af07ffd285bc743fcbdeace96f2b21d22", null ],
      [ "NC_OP_UNLOCK", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07aa4071db38c423865b24543cb504a4b42", null ],
      [ "NC_OP_COMMIT", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a350f96fd686eea971d1d9e087a9ff8f4", null ],
      [ "NC_OP_DISCARDCHANGES", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a59fd75a1b96a307a2d87e327c7d9a695", null ],
      [ "NC_OP_CREATESUBSCRIPTION", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07aafc549220669ed05b9c043b09be496fe", null ],
      [ "NC_OP_GETSCHEMA", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a213f30aeb2d0d09bc6de7d98015860c3", null ],
      [ "NC_OP_VALIDATE", "db/de9/group__rpc.html#gga3e6fc59e2d06c1c0edb36ee64ee9cc07a064e97e228090350548b4b67c6c598b0", null ]
    ] ],
    [ "NC_RPC_TYPE", "db/de9/group__rpc.html#ga4088fac1dd592062b27ff5b0e1708d00", [
      [ "NC_RPC_UNKNOWN", "db/de9/group__rpc.html#gga4088fac1dd592062b27ff5b0e1708d00ae27a06c29d4cb56cce4298bc54dc498a", null ],
      [ "NC_RPC_HELLO", "db/de9/group__rpc.html#gga4088fac1dd592062b27ff5b0e1708d00a4c352cf3bf15069fc76e4ac698de0a8c", null ],
      [ "NC_RPC_DATASTORE_READ", "db/de9/group__rpc.html#gga4088fac1dd592062b27ff5b0e1708d00ab9542d7955d9821f23b5909f3dbec7bb", null ],
      [ "NC_RPC_DATASTORE_WRITE", "db/de9/group__rpc.html#gga4088fac1dd592062b27ff5b0e1708d00ab283d1c39df65fe56607329bc3c946f9", null ],
      [ "NC_RPC_SESSION", "db/de9/group__rpc.html#gga4088fac1dd592062b27ff5b0e1708d00aa7e77d1cd094384f2683352c63a4fccb", null ]
    ] ],
    [ "nc_filter_free", "db/de9/group__rpc.html#ga0dbfd598d6fd303819817370cdf63229", null ],
    [ "nc_filter_new", "db/de9/group__rpc.html#ga599c715b0aee0f1f2ed231ce1d78e5bd", null ],
    [ "nc_rpc_build", "db/de9/group__rpc.html#ga5c4348c96b0d5e6a64f94dbbdeaf4100", null ],
    [ "nc_rpc_capability_attr", "db/de9/group__rpc.html#ga14f5e170cbc9acd9a146eee2fb6b796f", null ],
    [ "nc_rpc_commit", "db/de9/group__rpc.html#ga7977ca8b562643607b3c846ed36bbb23", null ],
    [ "nc_rpc_copyconfig", "db/de9/group__rpc.html#gaf7b76c1243dc218cf1dc8b17876e319c", null ],
    [ "nc_rpc_deleteconfig", "db/de9/group__rpc.html#gae1faa46f5048f21dc580d44836d848e8", null ],
    [ "nc_rpc_discardchanges", "db/de9/group__rpc.html#ga337ea7a9b006a79ee5ea615e9d9a5a6f", null ],
    [ "nc_rpc_dump", "db/de9/group__rpc.html#ga3e840368c40be2ea4d5201edbd3adaca", null ],
    [ "nc_rpc_dup", "db/de9/group__rpc.html#gadab3d916540f79dd2b168134758fe3d1", null ],
    [ "nc_rpc_editconfig", "db/de9/group__rpc.html#gae704e312c7aa5e6385abd4989e79398c", null ],
    [ "nc_rpc_free", "db/de9/group__rpc.html#ga4041bda37caa9eedb7a1e2534280f3df", null ],
    [ "nc_rpc_generic", "db/de9/group__rpc.html#gaa9ad7fac41fdef0063c2e2793fb19efd", null ],
    [ "nc_rpc_get", "db/de9/group__rpc.html#ga6818afbecf7fedf78f620162de78b4fd", null ],
    [ "nc_rpc_get_config", "db/de9/group__rpc.html#ga05a10e0b6c89ac04426410f399b87257", null ],
    [ "nc_rpc_get_defop", "db/de9/group__rpc.html#gaf867eacee93e3596371415d028e62d29", null ],
    [ "nc_rpc_get_erropt", "db/de9/group__rpc.html#ga488f894b9fa4866326837a9ed0575e36", null ],
    [ "nc_rpc_get_filter", "db/de9/group__rpc.html#ga05705bba8345c15637bc54cf6b9a4b3d", null ],
    [ "nc_rpc_get_msgid", "db/de9/group__rpc.html#gabc7eb11a4f2fdbe302a2430e00935c48", null ],
    [ "nc_rpc_get_ns", "db/de9/group__rpc.html#ga21ae2135af2588162112c13fb4095652", null ],
    [ "nc_rpc_get_op", "db/de9/group__rpc.html#gabf639574395456fb6f4bade36fb4babd", null ],
    [ "nc_rpc_get_op_content", "db/de9/group__rpc.html#gade3f111e7c7727d512313b4875fd8f50", null ],
    [ "nc_rpc_get_op_name", "db/de9/group__rpc.html#ga9796f2bc7841265d478891974eb610c6", null ],
    [ "nc_rpc_get_op_namespace", "db/de9/group__rpc.html#ga0b5d7acbcc0429fac6d5e3b509609bd8", null ],
    [ "nc_rpc_get_source", "db/de9/group__rpc.html#ga3fcf5083b04a294e935a2897c212065b", null ],
    [ "nc_rpc_get_target", "db/de9/group__rpc.html#gab240067d45d58c945cdfd61948751379", null ],
    [ "nc_rpc_get_testopt", "db/de9/group__rpc.html#gab12fec9068d72fa6817f4a59a81e625e", null ],
    [ "nc_rpc_get_type", "db/de9/group__rpc.html#gaa502fb30575000775b29a764101c1bef", null ],
    [ "nc_rpc_getconfig", "db/de9/group__rpc.html#ga4ae747c4c96e1d3621745e122091ba11", null ],
    [ "nc_rpc_getschema", "db/de9/group__rpc.html#ga3b762dd881622eaa72b08c9b58d76a5e", null ],
    [ "nc_rpc_killsession", "db/de9/group__rpc.html#gae9876e8d038eb81a376bd82a08c58b95", null ],
    [ "nc_rpc_lock", "db/de9/group__rpc.html#ga6a03d40e00fbe019a34541a55f3f4a31", null ],
    [ "nc_rpc_unlock", "db/de9/group__rpc.html#gad843551f9d1ff8be6a118d026e8b995a", null ],
    [ "nc_rpc_validate", "db/de9/group__rpc.html#ga14fa1c78362457a646d5d820206d5158", null ],
    [ "nc_session_recv_rpc", "db/de9/group__rpc.html#ga214fcc2c0095d56f4aa0d90c11da25fc", null ],
    [ "nc_session_send_recv", "db/de9/group__rpc.html#ga27d3fe78769630932a18c726df4fe6e6", null ],
    [ "nc_session_send_rpc", "db/de9/group__rpc.html#gaeb0d93ea1b5ef0c22c9e5372425fb5c3", null ]
];
